@@ -1,35 +1,43 @@
-<?php
+<?php declare(strict_types=1);
 /*
- * This file is part of php-file-iterator.
+ * This file is part of phpunit/php-file-iterator.
  *
  * (c) Sebastian Bergmann <sebastian@phpunit.de>
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-
 namespace SebastianBergmann\FileIterator;
 
+use const GLOB_ONLYDIR;
+use function array_filter;
+use function array_map;
+use function array_merge;
+use function glob;
+use function is_dir;
+use function is_string;
+use function realpath;
+use AppendIterator;
+use RecursiveDirectoryIterator;
+use RecursiveIteratorIterator;
+
 class Factory
 {
     /**
      * @param array|string $paths
      * @param array|string $suffixes
      * @param array|string $prefixes
-     * @param array        $exclude
-     *
-     * @return \AppendIterator
      */
-    public function getFileIterator($paths, $suffixes = '', $prefixes = '', array $exclude = []): \AppendIterator
+    public function getFileIterator($paths, $suffixes = '', $prefixes = '', array $exclude = []): AppendIterator
     {
-        if (\is_string($paths)) {
+        if (is_string($paths)) {
             $paths = [$paths];
         }
 
         $paths   = $this->getPathsAfterResolvingWildcards($paths);
         $exclude = $this->getPathsAfterResolvingWildcards($exclude);
 
-        if (\is_string($prefixes)) {
+        if (is_string($prefixes)) {
             if ($prefixes !== '') {
                 $prefixes = [$prefixes];
             } else {
@@ -37,7 +45,7 @@ class Factory
             }
         }
 
-        if (\is_string($suffixes)) {
+        if (is_string($suffixes)) {
             if ($suffixes !== '') {
                 $suffixes = [$suffixes];
             } else {
@@ -45,15 +53,15 @@ class Factory
             }
         }
 
-        $iterator = new \AppendIterator;
+        $iterator = new AppendIterator;
 
         foreach ($paths as $path) {
-            if (\is_dir($path)) {
+            if (is_dir($path)) {
                 $iterator->append(
                     new Iterator(
                         $path,
-                        new \RecursiveIteratorIterator(
-                            new \RecursiveDirectoryIterator($path, \RecursiveDirectoryIterator::FOLLOW_SYMLINKS | \RecursiveDirectoryIterator::SKIP_DOTS)
+                        new RecursiveIteratorIterator(
+                            new RecursiveDirectoryIterator($path, RecursiveDirectoryIterator::FOLLOW_SYMLINKS | RecursiveDirectoryIterator::SKIP_DOTS)
                         ),
                         $suffixes,
                         $prefixes,
@@ -71,13 +79,13 @@ class Factory
         $_paths = [];
 
         foreach ($paths as $path) {
-            if ($locals = \glob($path, GLOB_ONLYDIR)) {
-                $_paths = \array_merge($_paths, \array_map('\realpath', $locals));
+            if ($locals = glob($path, GLOB_ONLYDIR)) {
+                $_paths = array_merge($_paths, array_map('\realpath', $locals));
             } else {
-                $_paths[] = \realpath($path);
+                $_paths[] = realpath($path);
             }
         }
 
-        return $_paths;
+        return array_filter($_paths);
     }
 }
